@@ -1,6 +1,9 @@
 from typing import Optional, List, Dict
 
+from reqif.helpers.debug import auto_described
 
+
+@auto_described
 class ReqIFDataTypeDefinitionString:
     def __init__(  # pylint: disable=too-many-arguments
         self,
@@ -32,20 +35,80 @@ class ReqIFDataTypeDefinitionString:
         )
 
 
-class ReqIFDataTypeDefinitionInteger:
-    def __init__(
+@auto_described
+class ReqIFDataTypeDefinitionBoolean:
+    def __init__(  # pylint: disable=too-many-arguments
         self,
+        is_self_closed: bool,
+        description: Optional[str],
+        identifier: str,
+        last_change: Optional[str],
+        long_name: Optional[str],
+    ):
+        self.is_self_closed: bool = is_self_closed
+        self.description: Optional[str] = description
+        self.identifier: str = identifier
+        self.last_change: Optional[str] = last_change
+        self.long_name: Optional[str] = long_name
+
+    @staticmethod
+    def create(
+        identifier: str,
+    ) -> "ReqIFDataTypeDefinitionBoolean":
+        return ReqIFDataTypeDefinitionBoolean(
+            is_self_closed=True,
+            description=None,
+            identifier=identifier,
+            last_change=None,
+            long_name=None,
+        )
+
+
+@auto_described
+class ReqIFDataTypeDefinitionInteger:
+    def __init__(  # pylint: disable=too-many-arguments
+        self,
+        is_self_closed: bool,
         description: Optional[str],
         identifier: str,
         last_change: Optional[str],
         long_name: str,
+        max_value: Optional[str],
+        min_value: Optional[str],
     ):
+        self.is_self_closed: bool = is_self_closed
         self.description: Optional[str] = description
         self.identifier: str = identifier
         self.last_change: Optional[str] = last_change
         self.long_name: str = long_name
+        self.max_value: Optional[str] = max_value
+        self.min_value: Optional[str] = min_value
 
 
+@auto_described
+class ReqIFDataTypeDefinitionReal:  # pylint: disable=too-many-instance-attributes  # noqa: E501
+    def __init__(  # pylint: disable=too-many-arguments
+        self,
+        is_self_closed: bool,
+        accuracy: Optional[int],
+        description: Optional[str],
+        identifier: str,
+        last_change: Optional[str],
+        long_name: Optional[str],
+        max_value: Optional[float],
+        min_value: Optional[float],
+    ):
+        self.is_self_closed: bool = is_self_closed
+        self.accuracy: Optional[int] = accuracy
+        self.description: Optional[str] = description
+        self.identifier: str = identifier
+        self.last_change: Optional[str] = last_change
+        self.long_name: Optional[str] = long_name
+        self.max_value: Optional[float] = max_value
+        self.min_value: Optional[float] = min_value
+
+
+@auto_described
 class ReqIFEnumValue:
     def __init__(  # pylint: disable=too-many-arguments
         self,
@@ -75,6 +138,7 @@ class ReqIFEnumValue:
         )
 
 
+@auto_described
 class ReqIFDataTypeDefinitionEnumeration:  # pylint: disable=too-many-instance-attributes # noqa:E501
     def __init__(  # pylint: disable=too-many-arguments
         self,
@@ -111,6 +175,7 @@ class ReqIFDataTypeDefinitionEnumeration:  # pylint: disable=too-many-instance-a
         )
 
 
+@auto_described
 class ReqIFDataTypeDefinitionXHTML:
     def __init__(  # pylint: disable=too-many-arguments
         self,
@@ -125,3 +190,20 @@ class ReqIFDataTypeDefinitionXHTML:
         self.identifier: str = identifier
         self.last_change: Optional[str] = last_change
         self.long_name: Optional[str] = long_name
+
+
+@auto_described
+class ReqIFDataTypeDefinitionDateIdentifier:
+    def __init__(  # pylint: disable=too-many-arguments
+        self,
+        is_self_closed: bool,
+        description: Optional[str],
+        identifier: str,
+        last_change: Optional[str],
+        long_name: Optional[str],
+    ):
+        self.is_self_closed: bool = is_self_closed
+        self.description: Optional[str] = description
+        self.identifier: str = identifier
+        self.last_change: Optional[str] = last_change
+        self.long_name: Optional[str] = long_name
