@@ -1,9 +1,13 @@
 from typing import Optional
 
+from reqif.helpers.debug import auto_described
 
+
+@auto_described
 class ReqIFNamespaceInfo:  # pylint: disable=too-many-instance-attributes
     def __init__(  # pylint: disable=too-many-arguments
         self,
+        original_reqif_tag_dump: Optional[str],
         doctype_is_present: bool,
         encoding: str,
         namespace: Optional[str],
@@ -14,6 +18,7 @@ class ReqIFNamespaceInfo:  # pylint: disable=too-many-instance-attributes
         schema_location: Optional[str],
         language: Optional[str],
     ):
+        self.original_reqif_tag_dump: Optional[str] = original_reqif_tag_dump
         self.doctype_is_present: bool = doctype_is_present
         self.encoding: str = encoding
         self.namespace: Optional[str] = namespace
@@ -24,30 +29,13 @@ class ReqIFNamespaceInfo:  # pylint: disable=too-many-instance-attributes
         self.schema_location: Optional[str] = schema_location
         self.language: Optional[str] = language
 
-    def __str__(self) -> str:
-        return (
-            f"ReqIFNamespaceInfo("
-            f"encoding={self.encoding}"
-            ", "
-            f"namespace={self.namespace}"
-            ", "
-            f"configuration={self.configuration}"
-            ", "
-            f"schema_namespace={self.schema_namespace}"
-            ", "
-            f"schema_location={self.schema_location}"
-            f")"
-        )
-
-    def __repr__(self) -> str:
-        return self.__str__()
-
     @staticmethod
     def empty(
         namespace: Optional[str],
         configuration: Optional[str],
     ):
         return ReqIFNamespaceInfo(
+            original_reqif_tag_dump=None,
             doctype_is_present=True,
             encoding="UTF-8",
             namespace=namespace,
