@@ -1,6 +1,9 @@
 from typing import Optional
 
+from reqif.helpers.debug import auto_described
 
+
+@auto_described
 class ReqIFReqIFHeader:  # pylint: disable=too-many-instance-attributes
     def __init__(  # pylint: disable=too-many-arguments
         self,
