@@ -1,8 +1,10 @@
 from typing import Optional, Any
 
+from reqif.helpers.debug import auto_described
 from reqif.models.reqif_spec_object import SpecObjectAttribute
 
 
+@auto_described
 class ReqIFSpecRelation:  # pylint: disable=too-many-instance-attributes
     def __init__(  # pylint: disable=too-many-arguments
         self,
@@ -23,25 +25,3 @@ class ReqIFSpecRelation:  # pylint: disable=too-many-instance-attributes
         self.source: str = source
         self.target: str = target
         self.values_attribute: Optional[SpecObjectAttribute] = values_attribute
-
-    def __str__(self) -> str:
-        return (
-            f"ReqIFSpecRelation("
-            f"description: {self.description}"
-            ", "
-            f"identifier: {self.identifier}"
-            ", "
-            f"last_change: {self.last_change}"
-            ", "
-            f"relation_type_ref: {self.relation_type_ref}"
-            ", "
-            f"source: {self.source}"
-            ", "
-            f"target: {self.target}"
-            ", "
-            f"values_attribute: {self.values_attribute}"
-            f")"
-        )
-
-    def __repr__(self) -> str:
-        return self.__str__()
