@@ -1,11 +1,13 @@
 from typing import List, Optional
 
+from reqif.helpers.debug import auto_described
 from reqif.models.reqif_spec_hierarchy import (
     ReqIFSpecHierarchy,
 )
 from reqif.models.reqif_spec_object import SpecObjectAttribute
 
 
+@auto_described
 class ReqIFSpecification:  # pylint: disable=too-many-instance-attributes
     def __init__(  # pylint: disable=too-many-arguments
         self,
@@ -26,17 +28,3 @@ class ReqIFSpecification:  # pylint: disable=too-many-instance-attributes
         self.values: Optional[List[SpecObjectAttribute]] = values
         self.specification_type: Optional[str] = specification_type
         self.children: Optional[List[ReqIFSpecHierarchy]] = children
-
-    def __str__(self) -> str:
-        return (
-            f"ReqIFSpecification("
-            f"identifier: {self.identifier},"
-            f"last_change: {self.last_change},"
-            f"long_name: {self.long_name},"
-            f"values: {self.values},"
-            f"children: {self.children},"
-            f")"
-        )
-
-    def __repr__(self) -> str:
-        return self.__str__()
