@@ -1,8 +1,10 @@
 from typing import Dict, List, Any
 
+from reqif.helpers.debug import auto_described
 from reqif.models.reqif_spec_object import ReqIFSpecObject
 
 
+@auto_described
 class ReqIFObjectLookup:
     def __init__(
         self,
